<h1 align="center"> Auto-AuthNumber </h1>
<h4 align="center">This is a library about automatic number-taking of "General Chinese Author Number Table".</h4>
<p  align="center">
<a href="https://pypi.org/project/autoauthnumber/"><img src="https://img.shields.io/pypi/v/autoauthnumber"></a>
<a href="https://www.gnu.org/licenses/quick-guide-gplv3.zh-cn.html"><img src="https://img.shields.io/pypi/l/azurlanetoollib?color=green"></a>
<img src="https://img.shields.io/pypi/dd/autoauthnumber?color=yellow">
</p>
<hr />
# Open Source Download Link

## Relase From Pypi

<h4>https://pypi.org/project/autoauthnumber/ </h4>

# Information

This is a library about automatic number-taking of "General Chinese Author Number Table". At present, there is only one way to take the number, that is, directly looking up the table.In the future, we will adapt to a variety of author numbering methods, please wait.

# Copyright Information

## LICENSE

> Copyright (C) 2021-2023 Matt Belfast Brown  
> Copyright (C) 2021-2023 NWAFU LOVE BOOK STORE
>
> This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
> License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
> version.
>
> This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
> warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
>
> You should have received a copy of the GNU General Public License along with this program. If not,
> see <https://www.gnu.org/licenses/> .

## Author

### Author Information

> Author: ***Matt Belfast Brown*** or *Matt Brown* or *M.B.B.*（ **Name in English** ）
>> Also be called ***The Day of The Doctor*** ( **Network Nickname** )  
> > ***鈴木夢美*** or ***伊藤京介*** ( **Name in Japanese** )  
> > ***沈永基***，***皓月***，***飞瀑山人***，***衍枫阁主人*** ( **Name in Chinese, Style Name, Pseudonym, Alias** )

### Contact Details

> E-mail: ***thedayofthedo@gmail.com*** or ***thedayofthedoctor@foxmail.com***   
> TEL: ___+86-15841486187___
>
> Address: **Room 313, Apartment No. 14, South District, South Campus, Northwest A&F University, No. 22, Xinong Road,
Litai Street, Yangling District, Shaanxi Province, China**  
> Address: ***中国陕西省杨凌区李台街道西农路22号西北农林科技大学南校区南区14号公寓313宿舍***

## Update Log

### Version:

| Release Version |    Status     |  Release Date  | Update Info            | 
|----------------:|:-------------:|:--------------:|:-----------------------|
|       **1.2.2** | **available** | **2023-06-10** | **Add new character.** |
